@@ -1,5 +1,5 @@
 /* BFD back-end for TMS320C30 coff binaries.
-   Copyright (C) 1998-2022 Free Software Foundation, Inc.
+   Copyright (C) 1998-2025 Free Software Foundation, Inc.
    Contributed by Steven Haworth (steve@pm.cse.rmit.edu.au)
 
    This file is part of BFD, the Binary File Descriptor library.
@@ -162,7 +162,7 @@ reloc_processing (arelent *relent,
   rtype2howto (relent, reloc);
 
   if (reloc->r_symndx == -1 || symbols == NULL)
-    relent->sym_ptr_ptr = bfd_abs_section_ptr->symbol_ptr_ptr;
+    relent->sym_ptr_ptr = &bfd_abs_section_ptr->symbol;
   else if (reloc->r_symndx >= 0 && reloc->r_symndx < obj_conv_table_size (abfd))
     relent->sym_ptr_ptr = symbols + obj_convert (abfd)[reloc->r_symndx];
   else
@@ -171,7 +171,7 @@ reloc_processing (arelent *relent,
 	/* xgettext:c-format */
 	(_("%pB: warning: illegal symbol index %ld in relocs"),
 	 abfd, reloc->r_symndx);
-      relent->sym_ptr_ptr = bfd_abs_section_ptr->symbol_ptr_ptr;
+      relent->sym_ptr_ptr = &bfd_abs_section_ptr->symbol;
     }
   relent->addend = reloc->r_offset;
   relent->address -= section->vma;
@@ -200,6 +200,7 @@ const bfd_target tic30_coff_vec =
   15,				/* ar_max_namelen */
   0,				/* match priority.  */
   TARGET_KEEP_UNUSED_SECTION_SYMBOLS, /* keep unused section symbols.  */
+  TARGET_MERGE_SECTIONS,
   bfd_getb64, bfd_getb_signed_64, bfd_putb64,
   bfd_getb32, bfd_getb_signed_32, bfd_putb32,
   bfd_getb16, bfd_getb_signed_16, bfd_putb16,	/* data */
