@@ -1,6 +1,6 @@
 /* DWARF 2 low-level section code
 
-   Copyright (C) 1994-2024 Free Software Foundation, Inc.
+   Copyright (C) 1994-2025 Free Software Foundation, Inc.
 
    Adapted by Gary Funck (gary@intrepid.com), Intrepid Technology,
    Inc.  with support from Florida State University (under contract
@@ -122,10 +122,10 @@ dwarf2_section_info::read (struct objfile *objfile)
   bfd *abfd;
   gdb_byte *buf, *retbuf;
 
-  if (readin)
+  if (read_in)
     return;
   buffer = NULL;
-  readin = true;
+  read_in = true;
 
   if (empty ())
     return;
