@@ -19,7 +19,7 @@
 # the rest of the test can be complied with debug information.  Whilst we
 # are at it, also test functions with debug information and C functions too.
 
-if [target_info exists gdb,cannot_call_functions] {
+if {[target_info exists gdb,cannot_call_functions]} {
     unsupported "this target can not call functions"
     continue
 }
@@ -73,7 +73,7 @@ proc build_and_run_test { lang symbols } {
 
     clean_restart $::testfile
 
-    if ![runto_main] then {
+    if { ![runto_main] } {
 	return
     }
 
