@@ -311,17 +311,17 @@ sframe_header_sanity_check_p (const sframe_header *hp)
 /* Flip the start address pointed to by FP.  */
 
 static void
-flip_fre_start_address (char *addr, uint32_t fre_type)
+flip_fre_start_address (void *addr, uint32_t fre_type)
 {
   if (fre_type == SFRAME_FRE_TYPE_ADDR2)
     {
-      uint16_t *start_addr = (uint16_t *)addr;
-      swap_thing (*start_addr);
+      struct { uint16_t x; } ATTRIBUTE_PACKED *p = addr;
+      swap_thing (p->x);
     }
   else if (fre_type == SFRAME_FRE_TYPE_ADDR4)
     {
-      uint32_t *start_addr = (uint32_t *)addr;
-      swap_thing (*start_addr);
+      struct { uint32_t x; } ATTRIBUTE_PACKED *p = addr;
+      swap_thing (p->x);
     }
 }
 
@@ -628,7 +628,7 @@ flip_sframe (char *frame_buf, size_t buf_size, uint32_t to_foreign)
       if (fdes >= buf_end)
 	goto bad;
 
-      if (to_foreign && sframe_decode_fde (fdes, fdes - buf_end, ver,
+      if (to_foreign && sframe_decode_fde (fdes, buf_end - fdes, ver,
 					   &num_fres, &fre_type, &fre_offset,
 					   &fsz))
 	goto bad;
@@ -638,7 +638,7 @@ flip_sframe (char *frame_buf, size_t buf_size, uint32_t to_foreign)
 
       fde_bytes_flipped += fsz;
 
-      if (!to_foreign && sframe_decode_fde (fdes, fdes - buf_end, ver,
+      if (!to_foreign && sframe_decode_fde (fdes, buf_end - fdes, ver,
 					    &num_fres, &fre_type, &fre_offset,
 					    &fsz))
 	goto bad;
@@ -938,42 +938,34 @@ sframe_frame_row_entry_copy (sframe_frame_row_entry *dst,
    Returns 0 on success, SFRAME_ERR otherwise.  */
 
 static int
-sframe_decode_fre_start_address (const char *fre_buf,
+sframe_decode_fre_start_address (const void *fre_buf,
 				 uint32_t *fre_start_addr,
 				 uint32_t fre_type)
 {
   uint32_t saddr = 0;
   int err = 0;
-  size_t addr_size = 0;
-
-  addr_size = sframe_fre_start_addr_size (fre_type);
 
   if (fre_type == SFRAME_FRE_TYPE_ADDR1)
     {
-      uint8_t *uc = (uint8_t *)fre_buf;
-      saddr = (uint32_t)*uc;
+      const uint8_t *uc = fre_buf;
+      saddr = *uc;
     }
   else if (fre_type == SFRAME_FRE_TYPE_ADDR2)
     {
-      uint16_t *ust = (uint16_t *)fre_buf;
-      /* SFrame is an unaligned on-disk format.  Using memcpy helps avoid the
-	 use of undesirable unaligned loads.  See PR libsframe/29856.  */
-      uint16_t tmp = 0;
-      memcpy (&tmp, ust, addr_size);
-      saddr = (uint32_t)tmp;
+      /* SFrame is an unaligned on-disk format.  See PR libsframe/29856.  */
+      const struct { uint16_t x; } ATTRIBUTE_PACKED *p = fre_buf;
+      saddr = p->x;
     }
   else if (fre_type == SFRAME_FRE_TYPE_ADDR4)
     {
-      uint32_t *uit = (uint32_t *)fre_buf;
-      uint32_t tmp = 0;
-      memcpy (&tmp, uit, addr_size);
-      saddr = (uint32_t)tmp;
+      const struct { uint32_t x; } ATTRIBUTE_PACKED *p = fre_buf;
+      saddr = p->x;
     }
   else
-    return sframe_set_errno (&err, SFRAME_ERR_INVAL);
+    sframe_set_errno (&err, SFRAME_ERR_INVAL);
 
   *fre_start_addr = saddr;
-  return 0;
+  return err;
 }
 
 /* Decode a frame row entry FRE which starts at location FRE_BUF.  The function
@@ -1983,11 +1975,11 @@ sframe_encoder_write_fre (char *contents, sframe_frame_row_entry *frep,
 }
 
 /* Serialize the core contents of the SFrame section and write out to the
-   output buffer held in the encoder context ECTX.  Return SFRAME_ERR if
-   failure.  */
+   output buffer held in the encoder context ECTX.  Sort the SFrame FDEs on
+   start PC if SORT_FDE_P is true.  Return SFRAME_ERR if failure.  */
 
 static int
-sframe_encoder_write_sframe (sframe_encoder_ctx *ectx)
+sframe_encoder_write_sframe (sframe_encoder_ctx *ectx, bool sort_fde_p)
 {
   char *contents;
   size_t buf_size;
@@ -2067,12 +2059,13 @@ sframe_encoder_write_sframe (sframe_encoder_ctx *ectx)
   sframe_assert ((size_t)(contents - ectx->sfe_data) == buf_size);
 
   /* Sort the FDE table */
-  sframe_sort_funcdesc (ectx);
+  if (sort_fde_p)
+    sframe_sort_funcdesc (ectx);
 
   /* Sanity checks:
      - the FDE section must have been sorted by now on the start address
-     of each function.  */
-  if (!(sframe_encoder_get_flags (ectx) & SFRAME_F_FDE_SORTED)
+     of each function, if sorting was needed.  */
+  if ((sort_fde_p != (sframe_encoder_get_flags (ectx) & SFRAME_F_FDE_SORTED))
       || (fd_info == NULL))
     return sframe_set_errno (&err, SFRAME_ERR_FDE_INVAL);
 
@@ -2090,12 +2083,12 @@ sframe_encoder_write_sframe (sframe_encoder_ctx *ectx)
 }
 
 /* Serialize the contents of the encoder context ECTX and return the buffer.
-   ENCODED_SIZE is updated to the size of the buffer.
-   Sets ERRP if failure.  */
+   Sort the SFrame FDEs on start PC if SORT_FDE_P is true.  ENCODED_SIZE is
+   updated to the size of the buffer.  Sets ERRP if failure.  */
 
 char *
-sframe_encoder_write (sframe_encoder_ctx *ectx,
-		      size_t *encoded_size, int *errp)
+sframe_encoder_write (sframe_encoder_ctx *ectx, size_t *encoded_size,
+		      bool sort_fde_p, int *errp)
 {
   sframe_header *ehp;
   size_t hdrsize, fsz, fresz, bufsize;
@@ -2136,7 +2129,7 @@ sframe_encoder_write (sframe_encoder_ctx *ectx,
   foreign_endian = need_swapping (ehp->sfh_abi_arch);
 
   /* Write out the FDE Index and the FRE table in the sfe_data. */
-  if (sframe_encoder_write_sframe (ectx))
+  if (sframe_encoder_write_sframe (ectx, sort_fde_p))
     return sframe_ret_set_errno (errp, SFRAME_ERR_BUF_INVAL);
 
   /* Endian flip the contents if necessary.  */
